@@ -23,14 +23,14 @@ class DetailSerializerMixin(object):
 
     def get_object(self, queryset=None):
         if queryset is None:
-            queryset = self.filter_queryset(self.get_queryset(is_for_detail=True))
+            queryset = self.get_queryset_detail()
         return super(DetailSerializerMixin, self).get_object(queryset=queryset)
 
-    def get_queryset(self, is_for_detail=False):
-        if self.queryset_detail is not None and is_for_detail:
+    def get_queryset_detail(self):
+        if self.queryset_detail is not None:
             return self.queryset_detail._clone()  # todo: test _clone()
         else:
-            return super(DetailSerializerMixin, self).get_queryset()
+            return self.get_queryset()
 
 
 class PaginateByMaxMixin(object):
@@ -76,4 +76,4 @@ class NestedViewSetMixin(object):
                 )
                 query_value = self.kwargs.get(kwarg_name)
                 result[query_lookup] = query_value
-        return result
\ No newline at end of file
+        return result
