@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from django.core.exceptions import ImproperlyConfigured
+from django.core.urlresolvers import NoReverseMatch
 
 from rest_framework.routers import (
     DefaultRouter,
@@ -7,7 +8,10 @@ from rest_framework.routers import (
     Route,
     replace_methodname,
 )
-from rest_framework_extensions.utils import flatten
+from rest_framework import views
+from rest_framework.reverse import reverse
+from rest_framework.response import Response
+from rest_framework_extensions.utils import flatten, compose_parent_pk_kwarg_name
 from rest_framework_extensions.compat_drf import add_trailing_slash_if_needed
 
 
@@ -104,8 +108,8 @@ class ExtendedActionLinkRouterMixin(object):
             attr = getattr(viewset, methodname)
             httpmethods = getattr(attr, 'bind_to_methods', None)
             if httpmethods:
-                endpoint = getattr(attr, 'endpoint')
-                is_for_list = getattr(attr, 'is_for_list')
+                endpoint = getattr(attr, 'endpoint', methodname)
+                is_for_list = getattr(attr, 'is_for_list', False)
                 if endpoint in known_actions:
                     raise ImproperlyConfigured('Cannot use @action or @link decorator on '
                                                'method "%s" as %s is an existing route'
@@ -142,9 +146,87 @@ class ExtendedActionLinkRouterMixin(object):
         return dynamic_routes_instances
 
 
-class ExtendedSimpleRouter(ExtendedActionLinkRouterMixin, SimpleRouter):
+class NestedRegistryItem(object):
+    def __init__(self, router, parent_prefix, parent_item=None):
+        self.router = router
+        self.parent_prefix = parent_prefix
+        self.parent_item = parent_item
+
+    def register(self, prefix, viewset, base_name, parents_query_lookups):
+        self.router._register(
+            prefix=self.get_prefix(current_prefix=prefix, parents_query_lookups=parents_query_lookups),
+            viewset=viewset,
+            base_name=base_name,
+        )
+        return NestedRegistryItem(
+            router=self.router,
+            parent_prefix=prefix,
+            parent_item=self
+        )
+
+    def get_prefix(self, current_prefix, parents_query_lookups):
+        return '{0}/{1}'.format(
+            self.get_parent_prefix(parents_query_lookups),
+            current_prefix
+        )
+
+    def get_parent_prefix(self, parents_query_lookups):
+        prefix = '/'
+        current_item = self
+        i = len(parents_query_lookups) - 1
+        while current_item:
+            prefix = '{parent_prefix}/(?P<{parent_pk_kwarg_name}>[^/.]+)/{prefix}'.format(
+                parent_prefix=current_item.parent_prefix,
+                parent_pk_kwarg_name=compose_parent_pk_kwarg_name(parents_query_lookups[i]),
+                prefix=prefix
+            )
+            i -= 1
+            current_item = current_item.parent_item
+        return prefix.strip('/')
+
+
+class NestedRouterMixin(object):
+    def _register(self, *args, **kwargs):
+        return super(NestedRouterMixin, self).register(*args, **kwargs)
+
+    def register(self, *args, **kwargs):
+        self._register(*args, **kwargs)
+        return NestedRegistryItem(
+            router=self,
+            parent_prefix=self.registry[-1][0]
+        )
+
+    def get_api_root_view(self):
+        """
+        Return a view to use as the API root.
+        """
+        api_root_dict = {}
+        list_name = self.routes[0].name
+        for prefix, viewset, basename in self.registry:
+            api_root_dict[prefix] = list_name.format(basename=basename)
+
+        class APIRoot(views.APIView):
+            _ignore_model_permissions = True
+
+            def get(self, request, format=None):
+                ret = {}
+                for key, url_name in api_root_dict.items():
+                    try:
+                        ret[key] = reverse(url_name, request=request, format=format)
+                    except NoReverseMatch:
+                        pass
+                return Response(ret)
+
+        return APIRoot.as_view()
+
+
+class ExtendedRouterMixin(ExtendedActionLinkRouterMixin, NestedRouterMixin):
     pass
 
 
-class ExtendedDefaultRouter(ExtendedActionLinkRouterMixin, DefaultRouter):
+class ExtendedSimpleRouter(ExtendedRouterMixin, SimpleRouter):
+    pass
+
+
+class ExtendedDefaultRouter(ExtendedRouterMixin, DefaultRouter):
     pass
\ No newline at end of file
