@@ -19,6 +19,7 @@ def get_rest_framework_features():
     return {
         'router_trailing_slash': get_rest_framework_version() >= (2, 3, 6),
         'allow_dot_in_lookup_regex_without_trailing_slash': get_rest_framework_version() >= (2, 3, 8),
+        'use_dot_in_lookup_regex_by_default': get_rest_framework_version() >= (2, 4, 0),  # todo: test me
         'max_paginate_by': get_rest_framework_version() >= (2, 3, 8),
         'django_object_permissions_class': get_rest_framework_version() >= (2, 3, 8),
         'save_related_serializers': get_rest_framework_version() >= (2, 3, 8),  # todo: test me
@@ -29,7 +30,8 @@ def get_rest_framework_features():
 def get_django_features():
     # todo: test me
     return {
-        'has_odd_space_in_sql_query': django_version < (1, 7, 0)
+        'has_odd_space_in_sql_query': django_version < (1, 7, 0),
+        'caches_singleton': django_version >= (1, 7, 0),  # https://docs.djangoproject.com/en/dev/releases/1.7/#cache
     }
 
 
@@ -75,6 +77,15 @@ def compose_parent_pk_kwarg_name(value):
         value
     )
 
+def get_cache(alias):
+    # todo: test me
+    if get_django_features()['caches_singleton']:
+        from django.core.cache import caches
+        return caches[alias]
+    else:
+        from django.core.cache import get_cache as _get_cache
+        return _get_cache(alias)
+
 
 default_cache_key_func = DefaultKeyConstructor()
 default_object_cache_key_func = DefaultObjectKeyConstructor()
